@@ -75,16 +75,24 @@ class Resolver(BaseModel, T.Generic[NodeType]):
     _fields_to_return: T.Set[str] = PrivateAttr(None)
     _fields_to_include: T.Set[str] = PrivateAttr(default_factory=set)
 
+    @staticmethod
+    def replace_str_with_vars(s: str, d: dict) -> str:
+        if not s:
+            return ""
+        for var_name, var_val in d.items():
+            s = re.sub(
+                rf"(\$)({var_name})(\W*)", r"\1" + f"[({var_val})]" + r"\3", s
+            ).replace(f"[({var_val})]", f"{var_val}")
+        return s
+
     def to_compare_filter_str(self) -> str:
         q_str = self.all_filters_str()
-        # add extra str
-        q_str += f", {self._extra_fields}"
-        for var_name, var_val in self._query_variables.items():
-            q_str = re.sub(
-                rf"(\$)({var_name})(\W*)", r"\1" + f"[({var_val})]" + r"\3", q_str
-            ).replace(f"[({var_val})]", f"{var_val}")
+        q_str = self.replace_str_with_vars(s=q_str, d=self._query_variables)
         return q_str
 
+    def to_compare_extra_str(self) -> str:
+        return self.replace_str_with_vars(s=self._extra_fields, d=self._query_variables)
+
     def is_subset(self, other: "Resolver", should_debug: bool = False) -> bool:
         # first compare top level resolver, then go down from there
         # if self has more fields to return than other, self cannot be a subset
@@ -92,6 +100,12 @@ class Resolver(BaseModel, T.Generic[NodeType]):
             if should_debug:
                 print(f"self {self.__class__.__name__} has more fields than other")
             return False
+
+        # if other does not have all extra fields that self has, return false
+        if self._extra_fields:
+            if self.to_compare_extra_str() not in other.to_compare_extra_str():
+                return False
+
         # if self has different filters than other, self cannot be a subset
         if self.to_compare_filter_str() != other.to_compare_filter_str():
             if should_debug:
@@ -549,7 +563,7 @@ class Resolver(BaseModel, T.Generic[NodeType]):
         # pass on other fields as an "extra" dict
         # problem with this is aliases are currently also added to extra... do i want this?
         other_fields = set(raw_d.keys()) - self.get_aliases()
-        for field_name in other_fields:
+        for field_name in sorted(other_fields):
             resolver = self._nested_resolvers.resolver_from_field_name(field_name)
             if resolver is None:
                 message = f"No nested resolver for {field_name=} found."
